@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -107,20 +107,6 @@ sub import_into
 
 =item *
 
-Save and resume the PAD of the calling function, so that local variables are
-preserved:
-
- async sub with_pad
- {
-    my $x = func();
-
-    await $F;
-
-    print "I still have X: $x\n";
- }
-
-=item *
-
 Suspend and resume over other interesting types of context, such as BLOCK and
 various LOOPs:
 
